MaterializeResult

Struct MaterializeResult 

pub struct MaterializeResult<T> {
    pub data: T,
    pub usage: Option<TokenUsage>,
}
Result of a materialize call, containing both the data and optional usage information.

This struct wraps the deserialized data along with token usage metadata from the final successful LLM API call.

Example

use rstructor::{LLMClient, OpenAIClient, Instructor};
use serde::{Serialize, Deserialize};

#[derive(Instructor, Serialize, Deserialize)]
struct Person { name: String, age: u8 }

let client = OpenAIClient::from_env()?;
let result = client.materialize_with_metadata::<Person>("Describe a person").await?;

// Access the data directly
println!("Name: {}", result.data.name);

// Check token usage
if let Some(usage) = result.usage {
    println!("Used {} total tokens", usage.total_tokens());
}

Fields

data: T

The deserialized data

usage: Option<TokenUsage>

Token usage information (if available from the provider)

Implementations

Source

impl<T> MaterializeResult<T>

pub fn new(data: T, usage: Option<TokenUsage>) -> Self

Create a new MaterializeResult with data and usage

pub fn from_data(data: T) -> Self

Create a MaterializeResult with just data (no usage info)

pub fn map<U, F: FnOnce(T) -> U>(self, f: F) -> MaterializeResult<U>

Map the data to a new type