OpenAIModel

Enum OpenAIModel 

pub enum OpenAIModel {
Show 30 variants Gpt55Pro, Gpt55, Gpt54, Gpt54Mini, Gpt54Nano, Gpt52Pro, Gpt52, Gpt52ChatLatest, Gpt52Codex, Gpt51, Gpt5ChatLatest, Gpt5Pro, Gpt5, Gpt5Nano, Gpt5Mini, Gpt41, Gpt41Mini, Gpt41Nano, Gpt4O, Gpt4OMini, Gpt4Turbo, Gpt4, Gpt35Turbo, O4Mini, O3, O3Mini, O1, O1Mini, O1Pro, Custom(String),
}
OpenAI models available for completion

For the latest available models and their identifiers, check the OpenAI Models Documentation.

Using Custom Models

You can specify any model name as a string using Custom variant or FromStr:

use rstructor::OpenAIModel;
use std::str::FromStr;

// Using Custom variant
let model = OpenAIModel::Custom("gpt-4-custom".to_string());

// Using FromStr (useful for config files)
let model = OpenAIModel::from_str("gpt-4-custom").unwrap();

// Or use the convenience method
let model = OpenAIModel::from_string("gpt-4-custom");

Variants



Gpt55Pro

GPT-5.5 Pro (most capable GPT-5.5 model)



Gpt55

GPT-5.5 (latest frontier model for complex professional work)



Gpt54

GPT-5.4 (more affordable frontier model for complex professional work)



Gpt54Mini

GPT-5.4 Mini (lower-latency, lower-cost GPT-5.4-class model)



Gpt54Nano

GPT-5.4 Nano (cheapest GPT-5.4-class model for high-volume tasks)



Gpt52Pro

GPT-5.2 Pro (previous GPT-5.2 pro model)



Gpt52

GPT-5.2 (previous GPT-5.2 model)



Gpt52ChatLatest

GPT-5.2 Chat Latest (ChatGPT GPT-5.2 model)



Gpt52Codex

GPT-5.2 Codex (coding-focused GPT-5.2 model)



Gpt51

GPT-5.1 (GPT-5.1 model)



Gpt5ChatLatest

GPT-5 Chat Latest (ChatGPT GPT-5 model)



Gpt5Pro

GPT-5 Pro (most capable GPT-5 model)



Gpt5

GPT-5 (standard GPT-5 model)



Gpt5Nano

GPT-5 Nano (smallest GPT-5 model)



Gpt5Mini

GPT-5 Mini (smaller, faster GPT-5 model)



Gpt41

GPT-4.1 (GPT-4.1 model)



Gpt41Mini

GPT-4.1 Mini (smaller GPT-4.1)



Gpt41Nano

GPT-4.1 Nano (smallest GPT-4.1)



Gpt4O

GPT-4o (previous GPT-4o model, optimized for chat)



Gpt4OMini

GPT-4o Mini (smaller, faster, more cost-effective version)



Gpt4Turbo

GPT-4 Turbo (high-intelligence model)



Gpt4

GPT-4 (standard GPT-4 model)



Gpt35Turbo

GPT-3.5 Turbo (efficient model for simple tasks)



O4Mini

O4 Mini (previous small reasoning model)



O3

O3 (reasoning model)



O3Mini

O3 Mini (smaller reasoning model)



O1

O1 (reasoning model optimized for complex problem-solving)



O1Mini

O1 Mini (smaller reasoning model)



O1Pro

O1 Pro (most capable reasoning model)



Custom(String)

Custom model name (for new models, local LLMs, or OpenAI-compatible endpoints)

Implementations

Source

impl Model

pub fn as_str(&self) -> &str

pub fn from_string(name: impl Into<String>) -> Self

Create a model from a string. This is a convenience method that always succeeds.

If the string matches a known model variant, it returns that variant. Otherwise, it returns Custom(name).